@@ -2,5 +2,6 @@ from typing import Optional, Any
 
 
 def let_if(value, func) -> Optional[Any]:
-    if value:
+    if value is not None:
         return func(value)
+    return value
